@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #-----------------------------------------------------------------
-# Copyright (C) 2017, the Loge development team
+# Copyright (C) 2017-2020, the Loge development team
 #
 # This file is part of Loge
 # Loge is distributed under the terms of GNU General Public License
@@ -36,6 +36,9 @@ def main():
     WINDOW = Gui(appinfo.name, appinfo.version)
     #---
     WINDOW.connect_to_core(CORE)
+    #
+    CORE.refresh()
+    CORE.startpage()
     #---
     WINDOW.main_window.closeEvent = WINDOW.closeEvent
     WINDOW.show()
