@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
-#--------------------------------------------------------------------
-# Copyright (C) 2017, the Loge development team
+#-----------------------------------------------------------------
+# Copyright (C) 2020, the Loge development team
 #
 # This file is part of Loge
 # Loge is distributed under the terms of GNU General Public License
 # The full license can be found in 'license.txt'
 # Loge development team can be found in 'development.txt'
-#--------------------------------------------------------------------
+#-----------------------------------------------------------------
 
 '''
 ---------------------------------------------------------------------
@@ -18,4 +18,8 @@ Browser is a window where results of processing script are visible.
 from PyQt5.QtWidgets import QTextBrowser
 
 class Browser(QTextBrowser):
-    pass
+
+    def scroll_to_relposition(self, relposition):
+        absmaximum = self.verticalScrollBar().maximum()
+        absposition = relposition * absmaximum
+        self.verticalScrollBar().setValue(absposition)
\ No newline at end of file
